@@ -9,7 +9,7 @@
 
 
 from ipywidgets import Tab
-from cbm.ipycbm.utils import settings, help_docs, settings
+from cbm.ipycbm.utils import settings, help_docs
 from cbm.ipycbm.ipy_view import view_panel
 
 
@@ -19,7 +19,7 @@ def view_widget_box():
         tab_box = Tab(children=[view_panel.view(), help_docs.widget_box(),
                                 settings.main()])
 
-        tab_box.set_title(0, 'View Data')
+        tab_box.set_title(0, 'View single parcel')
         tab_box.set_title(1, 'Help')
         tab_box.set_title(2, 'Settings')
 
