@@ -7,4 +7,4 @@
 # Copyright : 2021 European Commission, Joint Research Centre
 # License   : 3-Clause BSD
 
-from cbm.show import background, chip_images, time_series
+from cbm.show import background, chip_images, time_series, parcel_info
