@@ -20,9 +20,9 @@ from skimage import exposure
 from datetime import datetime
 from rasterio.plot import show
 from descartes import PolygonPatch
-from cbm.get import parcel_info, chip_images
 from os.path import join, normpath, isfile, exists
 
+from cbm.get import parcel_info, chip_images
 from cbm.utils import data_options, raster_utils, config
 
 
@@ -42,9 +42,183 @@ def overlay_parcel(img, parcel, debug=False):
     return patches
 
 
+def by_location(lon, lat, start_date=None, end_date=None,
+                imgtype=['B04', 'B08'], chipsize=400, columns=4,
+                show_parcel=True,
+                cmap='RdYlGn_r', percentile=[2, 98],
+                clean_history=False,
+                view=True, hspace=0, debug=False):
+
+    if type(imgtype) is str:
+        bands = [imgtype]  # bands
+    else:
+        bands = imgtype
+
+    if bands[0].lower() == 'ndvi':
+        bands = ['B04', 'B08']
+    elif bands[0].lower().replace(' ', '_') == 'true_color':
+        bands = ['B04', 'B03', 'B02']
+
+    path = normpath(join(config.get_value(['paths', 'temp']),
+                         f"{lon}_{lat}".replace('.', '_')))
+
+    ci_path = normpath(join(path, 'chip_images'))
+    if clean_history:
+        if os.path.isdir(ci_path):
+            try:
+                rmtree(ci_path)
+            except Exception as err:
+                print("Could not delete directory:", ci_path, err)
+
+    same_chipsize = check_chipsize(ci_path, chipsize)
+    date_ranges = check_dates(ci_path, start_date, end_date)
+    if debug:
+        print('same args: ', same_chipsize)
+        print('date_ranges', date_ranges)
+
+    for b in bands:
+        csv_list_b = normpath(join(ci_path, f'images_list.{b}.csv'))
+        if debug:
+            print(csv_list_b)
+        if not exists(csv_list_b) or not same_chipsize:
+            chip_images.by_location(lon, lat, start_date, end_date,
+                                    b, chipsize, debug)
+        elif date_ranges:
+            for drange in date_ranges:
+                chip_images.by_location(lon, lat, drange[0], drange[1],
+                                        b, chipsize, debug)
+
+    # available_options = raster_utils.available_options(path, pid)
+
+    def multi_bands_imgs(bands, fname):
+        df = raster_utils.create_df(ci_path, 'pid', bands)
+        rows = round((df.shape[0] / columns) + 0.5)
+        fig = plt.figure(figsize=(16, 4 * rows))
+        for i, row in df.iterrows():
+            fig.add_subplot(rows, columns, i + 1)
+
+            str_date = str(row['date'].date()).replace('-', '')
+            img_png = normpath(join(ci_path, f'{fname}_{str_date}.png'))
+
+            # Create color image if it does not exist
+            # Merge bands (images path, export image path, bands list)
+            if not isfile(img_png) or not same_chipsize:
+                imgs_path = normpath(join(ci_path, row['imgs']))
+                raster_utils.merge_bands(imgs_path, img_png,
+                                         bands)
+
+            with rasterio.open(img_png, format='PNG') as img:
+                overlay_date(img, row['date'].date())  # Add date overlay.
+                ax = plt.gca()
+
+                plt.axis('off')  # Turn of axis.
+                pA, pB = np.percentile(
+                    img.read(1), tuple(percentile))
+
+                # Strech image to A - B percentile.
+                stack = [exposure.rescale_intensity(
+                    img.read()[i, :, :], in_range=(
+                        pA, pB)) for i in range(len(bands))]
+                rgb_enhanced = np.dstack(stack)
+
+                show(np.uint16(rgb_enhanced.transpose(2, 0, 1) / 300),
+                     ax=ax, transform=img.transform)
+        fig.subplots_adjust(wspace=0.03, hspace=hspace)
+        if not view:
+            plt.close(fig)
+            return fig
+        return plt.show(fig)
+
+    def ndvi_imgs(bands, fname):
+        df = raster_utils.create_df(ci_path, 'pid', bands)
+        rows = round((df.shape[0] / columns) + 0.5)
+        fig = plt.figure(figsize=(16, 4 * rows))
+        for i, row in df.iterrows():
+            fig.add_subplot(rows, columns, i + 1)
+
+            str_date = str(row['date'].date()).replace('-', '')
+            img_png = normpath(join(ci_path, f'{fname}_{str_date}.png'))
+
+            imgs_path = normpath(join(ci_path, row['imgs']))
+            b4f = f"{imgs_path}.B04.tif"
+            with rasterio.open(b4f, format='GTiff') as img:
+                overlay_date(img, row['date'].date())  # Add date overlay.
+                ax = plt.gca()
+
+            plt.axis('off')  # Turn of axis.
+            ndvi = raster_utils.calc_ndvi(imgs_path, img_png, bands)
+            pA, pB = np.percentile(
+                ndvi, tuple(percentile))
+
+            show(ndvi, ax=ax, transform=img.transform,
+                 cmap=cmap, vmin=pA, vmax=pB)
+
+            img.close()
+        fig.subplots_adjust(wspace=0.03, hspace=hspace)
+        if not view:
+            plt.close(fig)
+            return fig
+        return plt.show(fig)
+
+    def single_band(band):
+        df = raster_utils.create_df(ci_path, 'pid', bands)
+        rows = round((df.shape[0] / columns) + 0.5)
+        fig = plt.figure(figsize=(16, 4 * rows))
+        for i, row in df.iterrows():
+            fig.add_subplot(rows, columns, i + 1)
+            img_gtif = normpath(
+                join(ci_path, f"{row['imgs']}.{bands[0]}.tif"))
+            with rasterio.open(img_gtif, format='GTiff') as img:
+                overlay_date(img, row['date'].date())
+                plt.axis('off')
+                ax = plt.gca()
+
+                img_read = img.read(1)
+
+                pA, pB = np.percentile(
+                    img_read, tuple(percentile))
+                show(img.read(1), ax=ax, transform=img.transform,
+                     cmap=data_options.cmaps(bands[0]),
+                     vmin=pA, vmax=pB)
+        fig.subplots_adjust(wspace=0.03, hspace=hspace)
+        if not view:
+            plt.close(fig)
+            return fig
+        return plt.show(fig)
+
+    def overlay_date(img, date):
+        date_text = plt.text(
+            img.bounds.left + ((img.bounds.right - img.bounds.left) / 6.5),
+            img.bounds.top - ((img.bounds.top - img.bounds.bottom) / 6.5),
+            date, color='yellow', weight='bold', size=12, bbox=dict(
+                boxstyle="round", ec='yellow', fc='black', alpha=0.2))
+        return date_text
+
+    if len(bands) == 1 and bands[0][0].lower() == 'b':
+        return single_band(bands[0])
+    elif bands == ['B04', 'B08']:
+        return ndvi_imgs(bands, 'NDVI')
+    elif len(bands) == 3:
+        return multi_bands_imgs(bands, ('').join(bands))  # True color
+    else:
+        return f"""Not recognized images type {bands}.
+        (use: [B0x, B...], True color or NDVI)"""
+
+
 def grid(aoi, year, pid, start_date=None, end_date=None, imgtype=['B04', 'B08'],
          chipsize=400, columns=4, show_parcel=True, cmap='RdYlGn_r',
-         percentile=[2, 98], ptype='g', clean_history=False, debug=False):
+         percentile=[2, 98], ptype='g', clean_history=False,
+         view=True, hspace=0, debug=False):
+    return by_pid(aoi, year, pid, start_date, end_date, imgtype,
+                  chipsize, columns, show_parcel, cmap,
+                  percentile, ptype, clean_history,
+                  view, debug)
+
+
+def by_pid(aoi, year, pid, start_date=None, end_date=None,
+           imgtype=['B04', 'B08'], chipsize=400, columns=4, show_parcel=True,
+           cmap='RdYlGn_r', percentile=[2, 98], ptype='', clean_history=False,
+           view=True, hspace=0, debug=False):
 
     if type(imgtype) is str:
         bands = [imgtype]  # bands
@@ -146,7 +320,11 @@ def grid(aoi, year, pid, start_date=None, end_date=None, imgtype=['B04', 'B08'],
 
                 show(np.uint16(rgb_enhanced.transpose(2, 0, 1) / 300),
                      ax=ax, transform=img.transform)
-        return plt.show()
+        fig.subplots_adjust(wspace=0.03, hspace=hspace)
+        if not view:
+            plt.close(fig)
+            return fig
+        return plt.show(fig)
 
     def ndvi_imgs(bands, fname):
         df = raster_utils.create_df(ci_path, pid, bands)
@@ -182,7 +360,11 @@ def grid(aoi, year, pid, start_date=None, end_date=None, imgtype=['B04', 'B08'],
                  cmap=cmap, vmin=pA, vmax=pB)
 
             img.close()
-        return plt.show()
+        fig.subplots_adjust(wspace=0.03, hspace=hspace)
+        if not view:
+            plt.close(fig)
+            return fig
+        return plt.show(fig)
 
     def single_band(band):
         df = raster_utils.create_df(ci_path, pid, bands)
@@ -213,8 +395,11 @@ def grid(aoi, year, pid, start_date=None, end_date=None, imgtype=['B04', 'B08'],
                 show(img.read(1), ax=ax, transform=img.transform,
                      cmap=data_options.cmaps(bands[0]),
                      vmin=pA, vmax=pB)
-
-        return plt.show()
+        fig.subplots_adjust(wspace=0.03, hspace=hspace)
+        if not view:
+            plt.close(fig)
+            return fig
+        return plt.show(fig)
 
     def overlay_date(img, date):
         date_text = plt.text(
